      {******************************************************************}
      { LayeredWindow                                                    }
      {                                                                  }
      { home page : http://www.winningcubed.de                           }
      { email     : martin.walter@winningcubed.de                        }
      {                                                                  }
      { date      : 27-07-2007                                           }
      {                                                                  }
      { version   : 1.0                                                  }
      {                                                                  }
      { Use of this file is permitted for commercial and                 }
      { non-commercial use                                               }
      { This file (c) 2007 Martin Walter                                 }
      {                                                                  }
      { This Software is distributed on an "AS IS" basis, WITHOUT        }
      { WARRANTY OF ANY KIND, either express or implied.                 }
      {                                                                  }
      { *****************************************************************}

unit LayeredWindow;

interface

uses
  Windows, Graphics, Forms;

procedure SetLayered(const Form: TCustomForm; const Bitmap: TBitmap;
  Alpha: Byte);

procedure FadeIn(const Form: TCustomForm; const Bitmap: TBitmap;
  const Step: Double);

procedure FadeInExp(const Form: TCustomForm; const Bitmap: TBitmap;
  const Step: Integer);

procedure FadeOut(const Form: TCustomForm; const Bitmap: TBitmap;
  const Step: Double);

procedure FadeOutExp(const Form: TCustomForm; const Bitmap: TBitmap;
  const Step: Integer);

implementation

uses
  Types, Math;

procedure SetLayered(const Form: TCustomForm; const Bitmap: TBitmap;
  Alpha: Byte);
var
  BlendF: TBlendFunction;
  P: TPoint;
  Size: TSize;
begin
  if (Form = nil) or (Bitmap = nil) then
    Exit;
  Form.Width := Bitmap.Width;
  Form.Height := Bitmap.Height;

  setWindowLong(Form.Handle, GWL_EXSTYLE,
    getWindowLong(Form.Handle, GWL_EXSTYLE) or WS_EX_LAYERED);

  BlendF.BlendOp := AC_SRC_OVER;
  BlendF.BlendFlags := 0;
  BlendF.SourceConstantAlpha := Alpha;
  BlendF.AlphaFormat := AC_SRC_ALPHA;
  P := Point(0, 0);
  Size.cx := Bitmap.Width;
  Size.cy := Bitmap.Height;

  UpdateLayeredWindow(Form.Handle, 0, nil, @Size, Bitmap.Canvas.Handle, @P, 0,
    @BlendF, ULW_ALPHA);
end;

procedure FadeIn(const Form: TCustomForm; const Bitmap: TBitmap;
  const Step: Double);
var
  C: Double;
begin
  C := 0;
  while C <= 255 - Step do
  begin
    C := C + Step;
    SetLayered(Form, Bitmap, Round(C));
  end;
  if C <> 255 then
    SetLayered(Form, Bitmap, 255);
end;

procedure FadeInExp(const Form: TCustomForm; const Bitmap: TBitmap;
  const Step: Integer);
var
  C: Integer;
  Add: Double;
begin
  C := 0;
  Add := Step;
  while C <= 255 - Add do
  begin
    C := C + Round(Add);
    Add := Power(Add, 1.05);
    SetLayered(Form, Bitmap, C);
  end;
  if C <> 255 then
    SetLayered(Form, Bitmap, 255);
end;

procedure FadeOut(const Form: TCustomForm; const Bitmap: TBitmap;
  const Step: Double);
var
  C: Double;
begin
  C := 255;
  while C >= Step do
  begin
    C := C -  Step;
    SetLayered(Form, Bitmap, Round(C));
  end;
  if C <> 0 then
    SetLayered(Form, Bitmap, 0);
end;

procedure FadeOutExp(const Form: TCustomForm; const Bitmap: TBitmap;
  const Step: Integer);
var
  C: Integer;
  Add: Double;
begin
  C := 255;
  Add := Step;
  while C >= Add do
  begin
    C := C - Round(Add);
    Add := Power(Add, 0.95);
    SetLayered(Form, Bitmap, C);
  end;
  if C <> 0 then
    SetLayered(Form, Bitmap, 0);
end;

end.
 