      {******************************************************************}
      { LoadImage                                                        }
      {                                                                  }
      { home page : http://www.winningcubed.de                           }
      { email     : martin.walter@winningcubed.de                        }
      {                                                                  }
      { date      : 11-11-2007                                           }
      {                                                                  }
      { version   : 1.1                                                  }
      {                                                                  }
      { Use of this file is permitted for commercial and                 }
      { non-commercial use                                               }
      { This file (c) 2007 Martin Walter                                 }
      {                                                                  }
      { This Software is distributed on an "AS IS" basis, WITHOUT        }
      { WARRANTY OF ANY KIND, either express or implied.                 }
      {                                                                  }
      { *****************************************************************}

unit LoadImage;

interface

uses
  Windows, Graphics, GDIPOBJ;

function LoadBitmapFromResource(const AResName: WideString;
  AInstance: LongWord): TBitmap;

function LoadImageFromResource(const AResName: WideString;
  AInstance: LongWord): TGPImage;

function LoadImageFromFile(const AFileName: WideString): TBitmap;

function GPImageToBitmap(const GPImage: TGPImage): TBitmap;

implementation

uses
  ActiveX;

function GPImageToBitmap(const GPImage: TGPImage): TBitmap;
var
  GPGraphics: TGPGraphics;
  P: Pointer;
  W, H: Cardinal;
begin
  Result := nil;
  if Assigned(GPImage) then
  begin
    W := GPImage.GetWidth;
    H := GPImage.GetHeight;
    if (W > 0) and (H > 0) then
    begin
      Result := TBitmap.Create;
      Result.PixelFormat := pf32Bit;
      Result.Width := W;
      Result.Height := H;
      P := Result.ScanLine[H - 1];
      FillChar(P^, (W * H) shl 2, 0);
      GPGraphics := TGPGraphics.Create(Result.Canvas.Handle);
      try
        GPGraphics.DrawImage(GPImage, 0, 0, W, H);
      finally
        GPGraphics.Free;
      end;
    end;
  end;
end;

function LoadBitmapFromResource(const AResName: WideString;
  AInstance: LongWord): Graphics.TBitmap;
var
  Image: TGPImage;
begin
  Image := LoadImageFromResource(AResName, AInstance);
  if Assigned(Image) then
  begin
    Result := GPImageToBitmap(Image);
    Image.Free;
  end
  else
    Result := nil;
end;

function LoadImageFromFile(const AFileName: WideString): TBitmap;
var
  Image: TGPImage;
begin
  Image := TGPImage.Create(AFileName);
  try
    Result := GPImageToBitmap(Image);
  finally
    Image.Free;
  end;
end;

function LoadImageFromResource(const AResName: WideString;
  AInstance: LongWord): TGPImage;
var
  hResource: HRSRC;
  imageSize: DWORD;
  hResData: DWORD;
  pResourceData: Pointer;
  hBuffer: DWORD;
  pBuffer: Pointer;
  pStream: IStream;
begin
  Result := nil;

  hResource := FindResourceW(hInstance, PWideChar(AResName), PWideChar(RT_RCDATA));
  imageSize := SizeofResource(hInstance, hResource);
  hResData := LoadResource(hInstance, hResource);
  pResourceData := LockResource(hResData);

  hBuffer := GlobalAlloc(GMEM_MOVEABLE, imageSize);
  pBuffer := GlobalLock(hBuffer);

  CopyMemory(pBuffer, pResourceData, imageSize);
  pStream := nil;

  if CreateStreamOnHGlobal(hBuffer, FALSE, pStream) = S_OK then
    Result := TGPImage.Create(pStream);

  GlobalUnlock(hBuffer);
  GlobalFree(hBuffer);

  UnlockResource(hResData);
end;

end.
