unit Splash;

interface

uses
  Classes, Graphics, Forms,
  GDIPOBJ;

type
  TSplashForm = class(TForm)
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
  private
    FImage: TGPImage;
    FBitmap: TBitmap;
  public
    procedure FadeIn;
    procedure FadeOut;
    procedure UpdateText(const Text: WideString);
  end;

var
  SplashForm: TSplashForm;

implementation

{$R *.dfm}

{$R Splash.res Splash.rc}

uses
  Windows, SysUtils,
  GDIPAPI,
  LoadImage,
  LayeredWindow;

procedure TSplashForm.FormCreate(Sender: TObject);
var
  L, T: Integer;
begin
  // PNG laden
  FImage := LoadImageFromResource('SPLASH', HInstance);

  // Bitmap aus PNG erstellen
  FBitmap := GPImageToBitmap(FImage);

  // Fenstergre festlegen und Fenster zentrieren
  L := (Screen.Width - FBitmap.Width) div 2;
  T := (Screen.Height - FBitmap.Height) div 2;
  SetBounds(L, T, FBitmap.Width, FBitmap.Height);

  // Bild zuweisen
  SetLayered(Self, FBitmap, 0);
end;

procedure TSplashForm.FormDestroy(Sender: TObject);
begin
  FBitmap.Free;
  FImage.Free;
end;

procedure TSplashForm.FadeIn;
begin
  LayeredWindow.FadeIn(Self, FBitmap, 0.2);
end;

procedure TSplashForm.FadeOut;
begin
  LayeredWindow.FadeOut(Self, FBitmap, 0.2);
end;

procedure TSplashForm.UpdateText(const Text: WideString);
var
  Graphics: TGPGraphics;
  Font: TGPFont;
  Brush: TGPSolidBrush;
  FF: TGPFontFamily;
begin
  // Oberflche anlegen
  Graphics := TGPGraphics.Create(FImage);
  try
    // Flche lschen (Weies Rechteck zeichnen)
    Brush := TGPSolidBrush.Create(MakeColor(255, 255, 255));
    try
      Graphics.FillRectangle(Brush, 50, 80, 192, 20);
    finally
      Brush.Free;
    end;


    // Schrift erzeugen
    FF := TGPFontFamily.Create('MS Reference Sans Serif');
    Font := TGPFont.Create(FF, 16);

    // Schwarzer Pinsel
    Brush := TGPSolidBrush.Create(MakeColor(0, 0, 0));
    try
      // Antialiasing einstellen
      Graphics.SetSmoothingMode(4);

      // Text zeichnen
      Graphics.DrawString(Text, -1, Font, MakePoint(50.0, 80.0), Brush);
    finally
      Brush.Free;
      Font.Free;
      FF.Free;
    end;
  finally
    Graphics.Free;
  end;

  // Bitmap neu erzeugen
  FBitmap.Free;
  FBitmap := GPImageToBitmap(FImage);

  // Fenster aktualisieren
  SetLayered(Self, FBitmap, 255);
end;

end.
